@@ -532,6 +532,16 @@ impl ProcessMemory {
     pub fn base_size(&self) -> usize {
         self.base_size
     }
+
+    /// This will close the handles/task ports or detach from a ptrace(2) session, making the ProcessMemory object effectively useless with the exception of retaining data.
+    pub fn early_close(&mut self) {
+        #[cfg(target_family = "windows")]
+        close_valid_handle(self.handle as _);
+        #[cfg(target_os = "macos")]
+        mach::mach_port::mach_port_deallocate(mach::traps::mach_task_self(), self.handle as _);
+        #[cfg(target_vendor = "unknown")]
+        ptrace::detach(nix_pid, None).unwrap(); 
+    }
 }
 
 impl Drop for ProcessMemory {
